OiRA

Help

1. Priprema
2. Uključite
3. Prepoznavanje + procjena
4. Plan mjera
5. Završni dokumenti
6. Status 0%

# Izvješćivanje

Sada, kada ste dovršili identifikaciju svih rizika u vašoj organizaciji i oblikovali plan mjera, možete stvoriti izvješće s popisom svih rezultata. Ako želite, u polje ispod možete unijeti dodatne komentare koje bi trebalo uključiti u to izvješće.

Spremi i nastavi

Scroll to top
Back

## report.html

Više

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More